MockRemoteConfig class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pushUpdate(Map<String, dynamic> value) → void
Emits an onConfigUpdated event carrying value's keys.
setRemoteValues(Map<String, dynamic> value) → void
Sets the values a fetch() will activate. Call before launching the app.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited