MockFirebaseMessaging class

Properties

channel → MockMethodChannel
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deny() → void
grant() → void
init() → void
initialMessage(Map<String, dynamic>? message) → void
noInitialMessage() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
token(String value) → void
toString() String
A string representation of this object.
inherited
verify(String method) List<MethodCall>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

channelName → const String